bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 9. Aventiure
___________________________________________________
| ### <Do> si gevarn waren wol niwen tage ### do sprach von Tronege hagene nv hoert waz ich iv sage ### wir svmen vns mit den mæren ce wormz an den rin ### iwer boten solden nv ce bvrgvnden sin [314a] ### Do sprach der kvnich Gvnther ir habet mir war geseit ### vns wære ceder selben verte niemen so bereit ### als ir min frivnt her hagene nv ritet in min lant ### di mine hove reise tvt in niemen baz bechant
| ### Des antwrte hagene ich pin niht bote gvt ### lat mich pflegen der chamere beliben vf der flvt ### ia wil ich bi den vrowen behivten ir gewant ### vnz wir si bringen in der bvrgende lant
###### 529 | ### Nv pitet Sifride fveren di poteshapft ### der chan si wol gewerben mit ellenthaffter crapft ### ver sage er iv di <reise> ir svlt mit gvten siten ### dvrch iwer swester willen der bete in vrivntlichen piten
###### 530 | ### Er sande nach dem <reken> der chom do man in vant ### er sprach sit wir heim nahen in miniv lant ### <...old ich poten senden ... lieben swester min ### ... miner mvter daz ..r nahen an den Rin>
###### 531 | ### <Des> ger ich an ivch Sifrit nv leistet minen mvt ### daz ich ez iemer diene sprach der degen gvt ### <do> widerredete iz Sifrit der vil chvne man ### vnz daz in Gvnther sere vlegen began
###### 532 | ### <Er> sprach ir svlt riten dvrch <den> willen min ### vnt ovch dvrch Crimhilde daz shone magedin ### daz ez mit mir verdiene div herlichiv meit ### do daz gehorte Sifrit do was der recke vil bereit
###### 533 | ### <Nv> enbietet swaz ir wellet des wirt niht verdaget ### ich wil iz gerne werben dvrch di vil shonen meit ### <ziwiv> sold ich verzihen di ich in hercen han ### swaz ir gebietet daz ist alliz getan
###### 534 | ### So saget miner mvter Vten der chvnegin ### daz wir an dirre verte in hohen mvte sin ### lat wizzen mine brvder wi wir geworben han ### ir svlt ovch vnser frivnde disiv mære horen lan
###### 535 | ### Di minen schonen swester di svlt ir niht verdagen ### den min vnt Prvnnhilde dienest den svlt ir der mægde sagen ### vnt ovch dem gesinde vnt allen minen man ### dar nach ie ranch min herce wi wol ich daz ver endet han
###### 536 | ### vnt sagt Oertwine dem liebem næven min ### daz er heizze sidelen ce Wormez an den Rin ### vnt ander mine mage sol man wizzen lan ### ich wil mit Prvnnhilde groze hohzite han
###### 537 | ### vnt sage <miner> swester so si daz habe ver nomen ### daz ich mit miner swester si ce lande chomen
| ### Daz si mit vlize enpfahe di lieben triv [314b] tinne min ### daz wil <ich> immer diende vmb Crhimhilde sin
###### 538 | ### Sifrit der herre balde vrlovp genam ### von vrovn Prvnnhilde als im wol gezam ### <vnz> allem ir gesinde do reit ær an den rin ### ez chvnde in dirre werlde ein bot bezzer niht gesin
###### 539 | ### mit vier vnt zweinzech recken ce Wormez er do reit ### des chvneges chom er ane do daz wart geseit ### Allez daz gesinde mvte iamers not ### si vorhten daz ir herre dort beliben wære tot
###### 540 | ### dor beizten si von rossen vil hohe stvnt ir mvt ### vil schiere chom in Giselher der ivnge chvnech gvt
| ### Vnde Gernot sin brvder wi bald er do sprach ### do er den chvnich Gvnther niht bi Sifride sach
###### 541 | ### Sit willechomen Sifrit ir svlt mich wizen lan ### wa ir minen brvder den kvnich habt verlan ### div Prvnnhilde sterche in wen vns <hat> benomen ### so wære ir hohiv minne vns ce grozem shaden chomen
###### 542 | ### di angest lat beliben iv vnt den magen sin ### iv enbivtet sinen dienest der liebe hergeselle min ### den liez ich wol gesvnden er hat mich iv gesant ### daz ich sin bote wære mit mæren her in iwer lant
###### 543 | ### ir svlt daz ahten shiere swi so daz geshæhe ### daz ich di kvneginne von iwer swester sæhe
| ### Di sol ich lazen hoeren waz in enboten hat ### Gvnther vnt Prvennhilt ir dinch in hohe stat
###### 544 | ### Do sprach der ivnge Giselher da svlt ir zv zir gan ### da <habtir> miner swester vil liebe an getan ### si treit ovch michel sorge vmb den prvoder min ### div magt siht ivch gerne des wil ich iwer bvrge sin
###### 545 | ### do sprach der herre Sifrit swaz ich ir dienen chan ### daz sol vil willechlichen mit triwen sin getan ### wer saget nv den vrowen daz ich dar wil gan ### des wart do bote Giselher der vil wætliche man
###### 546 | ### Giselher der snelle zv siner mvter sprach ### vnt ovch ce siner swester da er si beide sach
| ### Vns ist chomen Sifrit der helt vz nider Lant ### in hat min brvder Gvnther her ce rine gesant
###### 547 | ### er bringet vns div mære wi ez vmb den kvnich ste ### nv svlt ir im erlovben daz er ce hove ge [315a] ### er sagt div rehten mære her von Islant ### noch was den edelen vrowen michel sorge bechant
###### 548 | ### si sprvngen nach ir wæte do leiten si sich an ### si baten Sifride hin ce hove gan
| ### Daz tet er willechlichen want er si gerne sach ### Crhimhilt div edele zv im gvetlichen sprach
###### 549 | ### sit willechom her Sifrit ritter lobelich ### wa ist min brvder Gvnther der edel kvnich rich ### Von Prvnnhilde chrepfte ich wæn wir in han verlorn ### owe mich armer mægde daz ich ce der werlt ie wart geborn
###### 550 | ### do sprah der ritter chvene nv gebt mir boten prot ### ir vil schone vrowen ir wæinet ane not ### Ich liez in wol gesvnden daz tvn ich iv bechant ### si habent mich iv beide mit den mæren her gesant
###### 551 | ### iv enbivtet holden dienest er vnt div wine sin ### mit vrivntlicher liebe vil edeliv chvenegin
| ### Nv lazet iwer weinen si wellent shiere chomen ### si het in manigen citen so liebez mære niht vernomen
###### 552 | ### mit snewizzen geren ir ovgen wolgetan ### wishete si nach trehin danchen si began ### Dem boten dirre mære div ir waren chomen ### do was ir michel trvren vnt ir weinen benomen
###### 553 | ### si bat den boten sitzen des was er vil bereit ### do sprach div minnechliche mir wære niht celeit ### Ob ich dem boten miete solde gebin min golt ### dar zv sit ir ce riche ich wil iv immer wesin holt
###### 554 | ### op ich nv eine hete sprach er drizech lant ### so enpfienge ich doh gerne gab vz iwerr hant
| ### Do sprach div <tvgentriche> nv sol ez sin getan ### si hiez den chamærær nach der boten miete gan
###### 555 | ### vier vnt zweinzech povge mit gesteine gvt ### di gap si im ce miete so stvnt des heldes mvt ### Er woldes niht behalden er gab iz sa cehant ### ir næhestim ingesinde di er ce kemnaten vant
###### 556 | ### ir mvter bot ir dienest in vil gvetlichen an ### ich sol iv sagen mære sprach der chvne man ### Wes ivch bitet Gvnther so er chvmt an den Rin ### ob ir daz vrowe leistet er welliv immer wæge sin
###### 557 | ### di sinen richen geste des hort ich in gern ### daz ir di wol enpfahet vnd svlt in des gewern
| ### Daz ir gegin im ritet fver Wormez an den sant ### des sit ir von dem chvenege mit rehten triwen gemant
###### 558 | ### do sprach div minnechliche des bin ich vil bereit ### swaz [315b] ich im chan gedienen daz ist im vnverseit ### Mit vrivntlichen triwen so sol ez sin getan ### do merte sich ir varwe di si vor liebe gewan
###### 559 | ### ez en wart nie bote enpfangen deheines fvrsten baz ### getorste si in chvessen div vrowe tæte daz ### Wi rehte minnechlich er von den vrowen shiet ### do taten Bvrgende als in Sifrit geriet
###### 560 | ### Sindolt vnt Hvnolt vnt Rvnolt der degen ### vil grozer vm mvze mvsen si do pflegen
| ### Rihten daz gesidele vor Wormez vf den sant ### des chvniges shapfere man mit arbeiten vant
###### 561 | ### Ortwin vnt Gere dine wolden daz niht lan ### si sanden nach den frivnden allenthalben dan ### Si chvndeten in di <hohzit> div da solde sin ### da cierten sich engegene div vil shonen magdin
###### 562 | ### der palas vnt di wende daz was vber al ### gecieret gegen den gesten der Gvntheres sal
| ### Der wart vil wol becimert dvrch manegen vremden man ### disiv vil starche hohzit div hvp sich vil vrolichen an
###### 563 | ### do ritten allenthalben di wæge dvrch daz lant ### der drier chvnege mage di hete man besant ### Daz si den solden warten di in da wolden chomen ### da wart vzer valde vil richer wæte genomen
###### 564 | ### do sagete man div mære daz man riten sach ### di Prvnnhilde vrivnde do hovp sich vngemach ### Von des volches crepfte in Bvrgenden lant ### hey waz man chvener dægene da ce beiden siten vant
###### 565 | ### do sprach div shone Crimhilt ir miniv magedin ### di an dem antpfange mit mir wellen sin
| ### Di svchen vz den chisten div aller besten chleit ### so wirt vns von den gesten lob vnt ere geseit
###### 566 | ### do chomen ovch di rechen di hiezen tragen dar ### di herlichen sætele von rotem golde gar ### Di vrowen solden riten ce Wormez an den rin ### bezzer pferht gereite div chvnden niender sin
###### 567 | ### hey waz da lihtes goldes von den moeren shein ### in lvhte von den zovmen vil manich edel stein ### Di gvldinen shaemel ob liehem pfelle gvt ### di braht man den vrowen si waren vrolich gemvt
###### 568 | ### vffe dem hove waren div vrowen pferht bereit ### den ædeln ivnchvrowen als ich iv han geseit
| ### Div smalen fvr bvge sach man di moeren tragen ### von den besten siden da von iv [316a] iemen chvnde gesagen
###### 569 | ### sehs vnt ahzech vrowen sach man da fver gan ### di gebende trvogen zv Crimhilde dan ### Chomen di vil schone vnt trvgen lihtiv kleit ### da chom ovch gecieret manich wætlichiv meit
###### 570 | ### fvmpfcech vnt viere von Bvergvnde lant ### ez waren ovch di hohsten di man da inder vant ### Di sach man da valvahse vnder liehten porten gan ### des ê der chvnich gerte daz wart mit vlize getan
###### 571 | ### si trvgen richen pfellel di besten di man vant ### vor den vremden recken so manich gvt gewant
| ### Daz ir genvege shone ce rehte wol gezam ### er wære in swachem mvte der ir deheiner wære gram
###### 572 | ### von zobel vnt von harme vil man da chleider vant ### da wart vil wol gecieret manich arm vnt hant ### Mit povgen ob den siden di si da solden tragen ### iv en chvnde diz vlizen ce ende niemen gesagen
###### 573 | ### vil manigen gvertel spæhen rich vnt lanch ### vber liehtiv chleider vil manich hant do swanch ### Vf edel roche ferrans von pfelle vz <Arabi> ### den ædelen ivnchvrowen was vil hoher frevden bi
###### 574 | ### ez wart in fvor gespenge manich shoniv meit ### genæt vil minnechliche ez moeht ir wesin leit
| ### Der ir vil liehtiv varwe niht lvhte gegen der wat ### so shones <ingesindes> nv niht chvnges chvnne hat
###### 575 | ### do di vil minnechlichen <nv> trvgen ir gewant ### di si da fvoren solden di chomen dar cehant ### Der hochmveten recken was ein vil michel crapft ### man trvch ovch dar mit shilden vil manich esshinen <schapft>

<<< Übersicht <<< vorige Seite nächste Seite >>>